from fastapi import APIRouter, Depends
from sqlalchemy.orm import Session
from app.db.database import get_db

router = APIRouter()

@router.get("/health", summary="Check service health")
def health_check(db: Session = Depends(get_db)):
    """
    Check the health status of the API and database connection.
    
    Returns:
        dict: Health status information
    """
    # Try to execute a simple query to verify DB connection
    try:
        db.execute("SELECT 1").fetchall()
        db_status = "healthy"
    except Exception as e:
        db_status = f"unhealthy: {str(e)}"
    
    return {
        "status": "ok",
        "database": db_status
    }